==> haskell-constraints-extras-0.3.2.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.3.2.1
visibility:           public
id:                   constraints-extras-0.3.2.1-HHrHEYpGPDd8L9e0crVARl
key:                  constraints-extras-0.3.2.1-HHrHEYpGPDd8L9e0crVARl
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  87cffdf7ba99d1bd3f96162c2f6a3d61
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.0.2/site-local/constraints-extras-0.3.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/constraints-extras-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.3.2.1-HHrHEYpGPDd8L9e0crVARl
depends:
    base-4.15.1.0 constraints-0.13.3-JbFHTU9aDfi6v8NowiY7KA
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-extras-0.3.2.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 constraints-extras
version:              0.3.2.1
visibility:           public
id:                   constraints-extras-0.3.2.1-1GzpuhLrLebA8QDDyXYW4e
key:                  constraints-extras-0.3.2.1-1GzpuhLrLebA8QDDyXYW4e
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  891311bbd09f3c3a64e82d07a074903e
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.0.2/site-local/constraints-extras-0.3.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/constraints-extras-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.3.2.1-1GzpuhLrLebA8QDDyXYW4e
depends:
    base-4.15.1.0 constraints-0.13.3-9FyqrwhIpXXH2n6htf6UXm
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
